<?php
/**
 * Appearance Settings
 *
 * @package Wellness_Coach_Lite
 */

function wellness_coach_lite_customize_register_appearance_new( $wp_customize ) {

    $wp_customize->add_panel( 
        'appearance_settings', 
        array(
            'title'       => __( 'Appearance Settings', 'wellness-coach-lite' ),
            'priority'    => 25,
            'capability'  => 'edit_theme_options',
            'description' => __( 'Change color and body background.', 'wellness-coach-lite' ),
        ) 
    );

    /** Typography */
    $wp_customize->add_section(
        'typography_settings',
        array(
            'title'    => __( 'Typography', 'wellness-coach-lite' ),
            'priority' => 50,
            'panel'    => 'appearance_settings',
        )
    );

    /** Primary Font */
    $wp_customize->add_setting(
        'primary_font',
        array(
            'default'			=> 'Questrial',
            'sanitize_callback' => 'wellness_coach_lite_sanitize_select'
        )
    );

    $wp_customize->add_control(
        new Wellness_Coach_Lite_Select_Control(
            $wp_customize,
            'primary_font',
            array(
                'label'	      => __( 'Primary Font', 'wellness-coach-lite' ),
                'description' => __( 'Primary font of the site.', 'wellness-coach-lite' ),
                'section'     => 'typography_settings',
                'choices'     => wellness_coach_lite_get_all_fonts(),	
                )
        )
    );

    /** Secondary Font */
    $wp_customize->add_setting(
        'secondary_font',
        array(
            'default'			=> 'Roboto Slab',
            'sanitize_callback' => 'wellness_coach_lite_sanitize_select'
        )
    );

    $wp_customize->add_control(
        new Wellness_Coach_Lite_Select_Control(
            $wp_customize,
            'secondary_font',
            array(
                'label'	      => __( 'Secondary Font', 'wellness-coach-lite' ),
                'description' => __( 'Secondary font of the site.', 'wellness-coach-lite' ),
                'section'     => 'typography_settings',
                'choices'     => wellness_coach_lite_get_all_fonts(),	
                )
        )
    ); 

    /** Font Size*/
    $wp_customize->add_setting( 
        'font_size', 
        array(
            'default'           => 18,
            'sanitize_callback' => 'wellness_coach_lite_sanitize_number_absint'
        ) 
    );
    
    $wp_customize->add_control(
        new Wellness_Coach_Lite_Slider_Control( 
            $wp_customize,
            'font_size',
            array(
                'section'	  => 'typography_settings',
                'label'		  => __( 'Font Size', 'wellness-coach-lite' ),
                'description' => __( 'Change the font size of your site.', 'wellness-coach-lite' ),
                'choices'	  => array(
                    'min' 	=> 10,
                    'max' 	=> 50,
                    'step'	=> 1,
                )                 
            )
        )
    );


    $wp_customize->get_section( 'colors' )->panel                          = 'appearance_settings';
    $wp_customize->get_section( 'colors' )->priority                       = 30;
    $wp_customize->get_section( 'background_image' )->panel                = 'appearance_settings';
    $wp_customize->get_section( 'background_image' )->priority             = 35;

}
add_action( 'customize_register', 'wellness_coach_lite_customize_register_appearance_new' );